pub struct Header {
pub packet_type: PacketType,
pub device_cid: U32,
pub host_cid: U32,
pub device_port: U32,
pub host_port: U32,
pub payload_len: U32,
/* private fields */
}Expand description
The packet header for a vsock packet passed over the usb vsock link. Each usb packet can contain one or more packets, each of which must start with a valid header and correct payload length.
Fields
packet_type: PacketTypeThe type of this packet
device_cid: U32For Connect, Reset, Accept, and Data packets this represents the device side’s address. Usually this will be a special value representing either that it is simply “the device”, or zero along with the rest of the cid and port fields to indicate that it’s a control stream packet. Must be zero for any other packet type.
host_cid: U32For Connect, Reset, Accept, and Data packets this represents the host side’s address. Usually this will be a special value representing either that it is simply “the host”, or zero along with the rest of the cid and port fields to indicate that it’s a control stream packet. Must be zero for any other packet type.
device_port: U32For Connect, Reset, Accept, and Data packets this represents the device side’s port. This must be a valid positive value for any of those packet types, unless all of the cid and port fields are also zero, in which case it is a control stream packet. Must be zero for any other packet type.
host_port: U32For Connect, Reset, Accept, and Data packets this represents the host side’s port. This must be a valid positive value for any of those packet types, unless all of the cid and port fields are also zero, in which case it is a control stream packet. Must be zero for any other packet type.
payload_len: U32The length of the packet payload. This must be zero for any packet type other than Data, Echo, EchoReply, or Pause.
Implementations
Sourceimpl Header
impl Header
Sourcepub fn new(packet_type: PacketType) -> Self
pub fn new(packet_type: PacketType) -> Self
Builds a new packet with correct magic value and packet type and all other fields initialized to zero.
Sourcepub fn packet_size(&self) -> usize
pub fn packet_size(&self) -> usize
Gets the size of this packet on the wire with the header and a payload of length
Self::payload_len.
Sourcepub fn set_address(&mut self, addr: &Address)
pub fn set_address(&mut self, addr: &Address)
Sets the address fields of this packet header based on the normalized address in addr.